---
name: Bug report
about: Create a bug report
title: ''
labels: ''
assignees: ''

---

Please provide the following information: 
 * Your python version (`python -V`):
 * Your pip version (`pip -V`):
   * If this isn't the [latest pip version](https://pip.pypa.io/en/stable/news/), have you checked using the latest pip version?
 * The version of the bindings you're using, if any (e.g. `pyo3`, `rust-cpython` or `cffi`):
 * Does `cargo build` work?
 * If on windows, have you checked that you aren't accidentally using unix path (those with the forward slash `/`)?

Please list the exact steps required to reproduce your error with all command output and if possible with a repository:
